@@ -18,7 +18,7 @@ class TextTransform:
 
         if chars_ == ['']:
             raise ValueError(
-                "Length of the unique characters set should be > 0. Expecting a .txt file with one character per line")
+                "Length of the unique characters set should be > 0. Expecting a `.txt` file with one character per line")
 
         all_chars = [c for c in special_chars if c not in chars_] + chars_
         self.chars = [c for c in all_chars]
@@ -36,7 +36,7 @@ class TextTransform:
     def get_num_classes(self):
         return len(self.char_map)
 
-    def get_blank_index(self):
+    def get_blank_index(self):  # this is more effective that always using len(char) which could be erroneous
         return self.blank_index
 
     def text_to_int(self, text):
@@ -50,9 +50,9 @@ class TextTransform:
                 ch = self.char_map[c]
                 track += c
             except KeyError:
-                print("Error for character `{}` in this sentence: {}".format(c, text))
+                print("Error for character `{}` in this sentence: {}. Repplacing with blank index.".format(c, text))
 
-                ch = 0
+                ch = self.get_blank_index()
             int_sequence.append(ch)
         return int_sequence
 
