@@ -1,18 +1,17 @@
 import os
-from okwugbe.model import SpeechRecognitionModel
 import torch
+import colorama
+import numpy as np
 import torch.nn as nn
 from torch import optim
 import torch.nn.functional as F
-from okwugbe.okwugbe_asr import OkwugbeDatasetForCommonVoice
+from okwugbe.model import SpeechRecognitionModel
+from okwugbe.okwugbe_asr import OkwugbeDataset, OkwugbeDatasetForCommonVoice
+from okwugbe.process import process
+from okwugbe.earlystopping import EarlyStopping
 from okwugbe.metrics import Metrics
 from okwugbe.decoder import Decoders
 from okwugbe.texttransform import TextTransform
-from okwugbe.okwugbe_asr import OkwugbeDataset
-from okwugbe.process import process
-from okwugbe.earlystopping import EarlyStopping
-import colorama
-import numpy as np
 from okwugbe.commonvoice import generate_character_set
 from IPython.display import Audio
 from IPython.core.display import display
@@ -183,7 +182,7 @@ def test(model, device, test_loader, criterion, text_transform):
 
             for j in range(len(decoded_preds)):
                 print("Decoding Speech's Content")
-                print(f'AUDIO PATH: {audio_file_paths[j]}')
+
                 display(Audio(str(audio_file_paths[j])))
                 test_cer.append(metrics.cer(decoded_targets[j], decoded_preds[j]))
                 test_wer.append(metrics.wer(decoded_targets[j], decoded_preds[j]))
@@ -242,27 +241,33 @@ def main(model, train_path, test_path, validation_size, learning_rate, batch_siz
     train_loader = torch.utils.data.DataLoader(dataset=train_dataset,
                                                batch_size=hparams['batch_size'],
                                                shuffle=True,
-                                               collate_fn=lambda x: process.data_processing(x, text_transform, 'train',
+                                               collate_fn=lambda x: process.data_processing(x, text_transform,
+                                                                                            data_type='train',
                                                                                             n_feats=n_feats,
                                                                                             freq_mask=freq_mask,
-                                                                                            time_mask=time_mask),
+                                                                                            time_mask=time_mask,
+                                                                                            common_voice=common_voice),
                                                **kwargs)
     valid_loader = torch.utils.data.DataLoader(dataset=valid_dataset,
                                                batch_size=hparams['batch_size'],
                                                shuffle=False,
-                                               collate_fn=lambda x: process.data_processing(x, text_transform, 'valid',
+                                               collate_fn=lambda x: process.data_processing(x, text_transform,
+                                                                                            data_type='valid',
                                                                                             n_feats=n_feats,
                                                                                             freq_mask=freq_mask,
-                                                                                            time_mask=time_mask),
+                                                                                            time_mask=time_mask,
+                                                                                            common_voice=common_voice),
                                                **kwargs)
 
     test_loader = torch.utils.data.DataLoader(dataset=test_dataset,
                                               batch_size=hparams['batch_size'],
                                               shuffle=False,
-                                              collate_fn=lambda x: process.data_processing(x, text_transform, 'test',
+                                              collate_fn=lambda x: process.data_processing(x, text_transform,
+                                                                                           data_type='test',
                                                                                            n_feats=n_feats,
                                                                                            freq_mask=freq_mask,
-                                                                                           time_mask=time_mask),
+                                                                                           time_mask=time_mask,
+                                                                                           common_voice=common_voice),
                                               **kwargs)
 
     model = model.to(device)
@@ -327,21 +332,21 @@ class Train_Okwugbe:
     def __init__(self, train_path=None, test_path=None, characters_set=None, n_cnn=5, n_rnn=3, rnn_dim=512,
                  num_layers=1, n_feats=128,
                  in_channels=1, out_channels=32, kernel=3, stride=2, padding=1, dropout=0.1, with_attention=False,
-                 batch_multiplier=1, grad_acc=False, model_path='okwugbe_model', learning_rate=3e-5, batch_size=80,
+                 batch_multiplier=1, grad_acc=False, model_path='okwugbe_model', learning_rate=3e-5, batch_size=20,
                  patience=20, epochs=500, optimizer='adamw', validation_size=0.2, lang=None, use_common_voice=False,
                  freq_mask=30, time_mask=100, display_plot=True):
-        if use_common_voice and lang is None:
+        if use_common_voice == True and lang == None:
             raise Exception(
                 f'`lang` (language from Common Voice) must be specified if use_common_voice is set to True.')
         self.common_voice = {'use_common_voice': use_common_voice, 'lang': lang}
 
-        if train_path is None and use_common_voice == False:
+        if train_path == None and use_common_voice == False:
             raise Exception(f'`train_path` cannot be None')
-        if test_path is None and use_common_voice == False:
+        if test_path == None and use_common_voice == False:
             raise Exception(f'`test_path` cannot be None')
         self.train_path = train_path
         self.test_path = test_path
-        if characters_set is None and use_common_voice == False:
+        if characters_set == None and use_common_voice == False:
             raise Exception(
                 f'You need to specify a `characters set .txt` file or use Common Voice data by specifying `use_common_voice=True`.')
         self.characters_set = characters_set if characters_set is not None else generate_character_set(lang)
@@ -360,7 +365,6 @@ class Train_Okwugbe:
         self.batch_multiplier = batch_multiplier
         self.grad_acc = grad_acc
         self.model_path = model_path
-        self.model_path = self.model_path + '_' + lang if lang is not None else self.model_path
         self.learning_rate = learning_rate
         self.batch_size = batch_size
         self.patience = patience
